@@ -2,16 +2,7 @@ from enum import Enum
 
 from checkout_sdk.common.common import Phone, Address
 from checkout_sdk.common.common import ResidentialStatusType, AccountHolderIdentification
-from checkout_sdk.common.enums import Currency, InstrumentType, Country, AccountType, AccountHolderType
-
-
-class EntityIdentificationType(str, Enum):
-    PASSPORT = 'passport'
-    NATIONAL_IDENTITY_CARD = 'national_identity_card'
-    DRIVING_LICENSE = 'driving_license'
-    CITIZEN_CARD = 'citizen_card'
-    RESIDENCE_PERMIT = 'residence_permit'
-    ELECTORAL_ID = 'electoral_id'
+from checkout_sdk.common.enums import Currency, InstrumentType, Country, AccountType, AccountHolderType, DocumentType
 
 
 class ScheduleFrequency(str, Enum):
@@ -49,15 +40,21 @@ class EntityEmailAddresses:
     primary: str
 
 
+class Invitee:
+    email: str
+
+
 class ContactDetails:
     phone: Phone
     email_addresses: EntityEmailAddresses
+    invitee: Invitee
 
 
 class Profile:
     urls: list
     mccs: list
     default_holding_currency: Currency
+    holding_currencies: list
 
 
 class EntityDocument:
@@ -66,7 +63,7 @@ class EntityDocument:
 
 
 class EntityIdentificationDocument:
-    type: EntityIdentificationType
+    type: DocumentType
     front: str
     back: str
 
@@ -86,6 +83,94 @@ class PlaceOfBirth:
     country: Country
 
 
+class CompanyVerificationType(str, Enum):
+    INCORPORATION_DOCUMENT = 'incorporation_document'
+    ARTICLES_OF_ASSOCIATION = 'articles_of_association'
+
+
+class CompanyVerification:
+    type: CompanyVerificationType
+    front: str
+
+
+class TaxVerificationType(str, Enum):
+    EIN_LETTER = 'ein_letter'
+
+
+class TaxVerification:
+    type: TaxVerificationType
+    front: str
+
+
+class ArticlesOfAssociationType(str, Enum):
+    MEMORANDUM_OF_ASSOCIATION = "memorandum_of_association"
+    ARTICLES_OF_ASSOCIATION = "articles_of_association"
+
+
+class BankVerificationType(str, Enum):
+    BANK_STATEMENT = 'bank_statement'
+
+
+class BankVerification:
+    type: BankVerificationType
+    front: str
+
+
+class ShareholderStructureType(str, Enum):
+    CERTIFIED_SHAREHOLDER_STRUCTURE = 'certified_shareholder_structure'
+
+
+class ShareholderStructure:
+    type: ShareholderStructureType
+    front: str
+
+
+class ProofOfLegalityType(str, Enum):
+    PROOF_OF_LEGALITY = 'proof_of_legality'
+
+
+class ProofOfLegality:
+    type: ProofOfLegalityType
+    front: str
+
+
+class ProofOfPrincipalAddressType(str, Enum):
+    PROOF_OF_ADDRESS = 'proof_of_address'
+
+
+class ProofOfPrincipalAddress:
+    type: ProofOfPrincipalAddressType
+    front: str
+
+
+class AdditionalDocument:
+    front: str
+
+
+class FinancialVerificationType(str, Enum):
+    FINANCIAL_STATEMENT = 'financial_statement'
+
+
+class FinancialVerification:
+    type: FinancialVerificationType
+    front: str
+
+
+class OnboardSubEntityDocuments:
+    identity_verification: EntityIdentificationDocument
+    company_verification: CompanyVerification
+    articles_of_association: ArticlesOfAssociationType
+    bank_verification: BankVerification
+    shareholder_structure: ShareholderStructure
+    proof_of_legality: ProofOfLegality
+    proof_of_principal_address: ProofOfPrincipalAddress
+    additional_document1: AdditionalDocument
+    additional_document2: AdditionalDocument
+    additional_document3: AdditionalDocument
+    tax_verification: TaxVerification
+    financial_verification: FinancialVerification
+
+
 class EntityRepresentative:
     first_name: str
     middle_name: str
@@ -96,6 +181,7 @@ class EntityRepresentative:
     date_of_birth: DateOfBirth
     place_of_birth: PlaceOfBirth
     roles: list  # accounts.EntityRoles
+    documents: OnboardSubEntityDocuments
 
 
 class EntityFinancialDocuments:
@@ -108,6 +194,12 @@ class EntityFinancialDetails:
     average_transaction_value: int
     highest_transaction_value: int
     documents: EntityFinancialDocuments
+    currency: Currency
+
+
+class DateOfIncorporation:
+    month: int
+    year: int
 
 
 class Company:
@@ -115,10 +207,12 @@ class Company:
     business_type: BusinessType
     legal_name: str
     trading_name: str
+    date_of_incorporation: DateOfIncorporation
+    regulatory_licence_number: str
     principal_address: Address
     registered_address: Address
-    document: EntityDocument
     representatives: list  # EntityRepresentative
+    document: EntityDocument
     financial_details: EntityFinancialDetails
 
 
@@ -137,14 +231,34 @@ class Individual:
     date_of_birth: DateOfBirth
     place_of_birth: PlaceOfBirth
     identification: Identification
+    financial_details: EntityFinancialDetails
+
+
+class ProcessingDetails:
+    settlement_country: str
+    target_countries: list  # str
+    annual_processing_volume: int
+    average_transaction_value: int
+    highest_transaction_value: int
+    currency: Currency
+
+
+class AdditionalInfo:
+    field1: str
+    field2: str
+    field3: str
 
 
 class OnboardEntityRequest:
     reference: str
-    contact_details: ContactDetails
+    is_draft: bool
     profile: Profile
+    contact_details: ContactDetails
     company: Company
+    processing_details: ProcessingDetails
     individual: Individual
+    documents: OnboardSubEntityDocuments
+    additional_info: AdditionalInfo
 
 
 class InstrumentDocument:
@@ -166,6 +280,10 @@ class InstrumentDetailsSepa(InstrumentDetails):
     swift_bic: str
 
 
+class InstrumentDetailsCardToken(InstrumentDetails):
+    token: str
+
+
 class BankDetails:
     name: str
     branch: str
@@ -212,7 +330,7 @@ class AccountsPaymentInstrument:
 
 class PaymentInstrumentRequest:
     label: str
-    type = InstrumentType.BANK_ACCOUNT
+    type = InstrumentType
     currency: Currency
     country: Country
     default: bool
@@ -220,9 +338,14 @@ class PaymentInstrumentRequest:
     instrument_details: InstrumentDetails
 
 
+class Headers:
+    if_match: str
+
+
 class UpdatePaymentInstrumentRequest:
     label: str
     default: bool
+    headers: Headers
 
 
 class ScheduleRequest:
