@@ -470,6 +470,12 @@ class PaymentSourceType(str, Enum):
     ALMA = 'alma'
     TRUSTLY = 'trustly'
     CVCONNECT = 'cvconnect'
+    SEPA = 'sepa'
+    ACH = 'ach'
+    BIZUM = 'bizum'
+    OCTOPUS = 'octopus'
+    PLAID = 'plaid'
+    SEQURA = 'sequra'
 
 
 class ChallengeIndicator(str, Enum):
@@ -483,6 +489,8 @@ class InstrumentType(str, Enum):
     BANK_ACCOUNT = 'bank_account'
     TOKEN = 'token'
     CARD = 'card'
+    SEPA = 'sepa'
+    CARD_TOKEN = 'card_token'
 
 
 class AccountType(str, Enum):
@@ -503,3 +511,41 @@ class AccountHolderIdentificationType(str, Enum):
     NATIONAL_ID = 'national_id'
     COMPANY_REGISTRATION = 'company_registration'
     TAX_ID = 'tax_id'
+
+
+class DocumentType(str, Enum):
+    PASSPORT = 'passport'
+    NATIONAL_IDENTITY_CARD = 'national_identity_card'
+    DRIVING_LICENSE = 'driving_license'
+    CITIZEN_CARD = 'citizen_card'
+    RESIDENCE_PERMIT = 'residence_permit'
+    ELECTORAL_ID = 'electoral_id'
+
+
+class AccountChangeIndicatorType(str, Enum):
+    THIS_TRANSACTION = "this_transaction"
+    LESS_THAN_THIRTY_DAYS = "less_than_thirty_days"
+    THIRTY_TO_SIXTY_DAYS = "thirty_to_sixty_days"
+    MORE_THAN_SIXTY_DAYS = "more_than_sixty_days"
+
+
+class AccountPasswordChangeIndicatorType(str, Enum):
+    NO_CHANGE = "no_change"
+    THIS_TRANSACTION = "this_transaction"
+    LESS_THAN_THIRTY_DAYS = "less_than_thirty_days"
+    THIRTY_TO_SIXTY_DAYS = "thirty_to_sixty_days"
+    MORE_THAN_SIXTY_DAYS = "more_than_sixty_days"
+
+
+class AccountTypeCardProductType(str, Enum):
+    CREDIT = "credit"
+    DEBIT = "debit"
+    NOT_APPLICABLE = "not_applicable"
+
+
+class CardholderAccountAgeIndicatorType(str, Enum):
+    LESS_THAN_THIRTY_DAYS = "less_than_thirty_days"
+    MORE_THAN_SIXTY_DAYS = "more_than_sixty_days"
+    NO_ACCOUNT = "no_account"
+    THIRTY_TO_SIXTY_DAYS = "thirty_to_sixty_days"
+    THIS_TRANSACTION = "this_transaction"
