@@ -39,7 +39,17 @@ class OAuthScopes(str, Enum):
     BALANCES_VIEW = 'balances:view'
     REPORTS = 'reports'
     REPORTS_VIEW = 'reports:view'
+    FINANCIAL_ACTIONS = 'financial-actions'
+    FINANCIAL_ACTIONS_VIEW = 'financial-actions:view'
 
     MIDDLEWARE = 'middleware'
     MIDDLEWARE_MERCHANTS_SECRET = 'middleware:merchants-secret'
     MIDDLEWARE_MERCHANTS_PUBLIC = 'middleware:merchants-public'
+    ISSUING_CLIENT = 'issuing:client'
+    ISSUING_CARD_MGMT = 'issuing:card-mgmt'
+    ISSUING_CONTROLS_READ = 'issuing:controls-read'
+    ISSUING_CONTROLS_WRITE = 'issuing:controls-write'
+
+    PAYMENT_CONTEXTS = 'Payment Contexts'
+
+    FORWARD = 'forward'
